@@ -6,7 +6,7 @@ use Text::CSV_XS;
 use Scalar::Util qw( reftype );
 use List::Util qw( max );
 use Cwd;
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 use Parse::Taxonomy::Auxiliary qw(
     path_check_fields
     components_check_fields
@@ -870,6 +870,11 @@ non-materialized-path fields in the records in the original taxonomy-by-material
 
 See documentation for C<write_adjacentified_to_csv()> for example.
 
+Note that the order in which C<adjacentify()> will assign C<id> and
+C<parent_id> values to records in the taxonomy-by-adjacent-list will almost
+certainly B<not> match the order in which elements appear in a CSV file or in
+the data structure returned by a method such as C<data_records()>.
+
 =back
 
 =cut
